@@ -1,5 +1,5 @@
 package Yancy;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: A simple CMS for administrating data
 
 #pod =head1 SYNOPSIS
@@ -134,7 +134,10 @@ our $VERSION = '0.002';
 #pod             people => {
 #pod                 type => 'object',
 #pod                 properties => {
-#pod                     id => { type => 'integer' },
+#pod                     id => {
+#pod                         type => 'integer',
+#pod                         readOnly => 1,
+#pod                     },
 #pod                     name => { type => 'string' },
 #pod                     email => { type => 'string' },
 #pod                 },
@@ -193,6 +196,7 @@ our $VERSION = '0.002';
 #pod             properties => {
 #pod                 id => {
 #pod                     type => 'integer',
+#pod                     readOnly => 1,
 #pod                 },
 #pod                 name => {
 #pod                     type => 'string',
@@ -217,15 +221,15 @@ our $VERSION = '0.002';
 #pod
 #pod =item * C<< type => "number" >> - A number field (C<< <input type="number" > >>)
 #pod
-#pod =item * C<< format => "date" >> - A date field (C<< <input type="date"> >>)
+#pod =item * C<< type => "string", format => "date" >> - A date field (C<< <input type="date"> >>)
 #pod
-#pod =item * C<< format => "date-time" >> - A date/time field (C<< <input type="datetime-local"> >>)
+#pod =item * C<< type => "string", format => "date-time" >> - A date/time field (C<< <input type="datetime-local"> >>)
 #pod
-#pod =item * C<< format => "email" >> - A e-mail address (C<< <input type="email"> >>)
+#pod =item * C<< type => "string", format => "email" >> - A e-mail address (C<< <input type="email"> >>)
 #pod
-#pod =item * C<< format => "url" >> - A URL input (C<< <input type="url"> >>)
+#pod =item * C<< type => "string", format => "url" >> - A URL input (C<< <input type="url"> >>)
 #pod
-#pod =item * C<< format => "tel" >> - A telephone number (C<< <input type="tel"> >>)
+#pod =item * C<< type => "string", format => "tel" >> - A telephone number (C<< <input type="tel"> >>)
 #pod
 #pod =back
 #pod
@@ -264,6 +268,7 @@ our $VERSION = '0.002';
 #pod             properties => {
 #pod                 id => {
 #pod                     type => 'integer',
+#pod                     readOnly => 1,
 #pod                 },
 #pod                 name => {
 #pod                     type => 'string',
@@ -354,7 +359,7 @@ Yancy - A simple CMS for administrating data
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -484,7 +489,10 @@ parts are described below. An example configuration file looks like:
             people => {
                 type => 'object',
                 properties => {
-                    id => { type => 'integer' },
+                    id => {
+                        type => 'integer',
+                        readOnly => 1,
+                    },
                     name => { type => 'string' },
                     email => { type => 'string' },
                 },
@@ -543,6 +551,7 @@ this:
             properties => {
                 id => {
                     type => 'integer',
+                    readOnly => 1,
                 },
                 name => {
                     type => 'string',
@@ -567,15 +576,15 @@ the object's properties.
 
 =item * C<< type => "number" >> - A number field (C<< <input type="number" > >>)
 
-=item * C<< format => "date" >> - A date field (C<< <input type="date"> >>)
+=item * C<< type => "string", format => "date" >> - A date field (C<< <input type="date"> >>)
 
-=item * C<< format => "date-time" >> - A date/time field (C<< <input type="datetime-local"> >>)
+=item * C<< type => "string", format => "date-time" >> - A date/time field (C<< <input type="datetime-local"> >>)
 
-=item * C<< format => "email" >> - A e-mail address (C<< <input type="email"> >>)
+=item * C<< type => "string", format => "email" >> - A e-mail address (C<< <input type="email"> >>)
 
-=item * C<< format => "url" >> - A URL input (C<< <input type="url"> >>)
+=item * C<< type => "string", format => "url" >> - A URL input (C<< <input type="url"> >>)
 
-=item * C<< format => "tel" >> - A telephone number (C<< <input type="tel"> >>)
+=item * C<< type => "string", format => "tel" >> - A telephone number (C<< <input type="tel"> >>)
 
 =back
 
@@ -614,6 +623,7 @@ property, which must be an array of property names.
             properties => {
                 id => {
                     type => 'integer',
+                    readOnly => 1,
                 },
                 name => {
                     type => 'string',
