@@ -1,5 +1,5 @@
 package Yancy::Backend::Dbic;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: A backend for DBIx::Class schemas
 
 #pod =head1 SYNOPSIS
@@ -59,14 +59,20 @@ our $VERSION = '0.002';
 #pod         collections => {
 #pod             People => {
 #pod                 properties => {
-#pod                     id => { type => 'integer' },
+#pod                     id => {
+#pod                         type => 'integer',
+#pod                         readOnly => 1,
+#pod                     },
 #pod                     name => { type => 'string' },
 #pod                     email => { type => 'string' },
 #pod                 },
 #pod             },
 #pod             Business => {
 #pod                 properties => {
-#pod                     id => { type => 'integer' },
+#pod                     id => {
+#pod                         type => 'integer',
+#pod                         readOnly => 1,
+#pod                     },
 #pod                     name => { type => 'string' },
 #pod                     email => { type => 'string' },
 #pod                 },
@@ -147,7 +153,7 @@ Yancy::Backend::Dbic - A backend for DBIx::Class schemas
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -206,14 +212,20 @@ You could map that schema to the following collections:
         collections => {
             People => {
                 properties => {
-                    id => { type => 'integer' },
+                    id => {
+                        type => 'integer',
+                        readOnly => 1,
+                    },
                     name => { type => 'string' },
                     email => { type => 'string' },
                 },
             },
             Business => {
                 properties => {
-                    id => { type => 'integer' },
+                    id => {
+                        type => 'integer',
+                        readOnly => 1,
+                    },
                     name => { type => 'string' },
                     email => { type => 'string' },
                 },
