@@ -1,5 +1,5 @@
 package Yancy::Backend::Mysql;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: A backend for MySQL using Mojo::mysql
 
 #pod =head1 SYNOPSIS
@@ -68,7 +68,10 @@ our $VERSION = '0.002';
 #pod             People => {
 #pod                 required => [ 'name', 'email' ],
 #pod                 properties => {
-#pod                     id => { type => 'integer' },
+#pod                     id => {
+#pod                         type => 'integer',
+#pod                         readOnly => 1,
+#pod                     },
 #pod                     name => { type => 'string' },
 #pod                     email => { type => 'string' },
 #pod                 },
@@ -76,7 +79,10 @@ our $VERSION = '0.002';
 #pod             Business => {
 #pod                 required => [ 'name' ],
 #pod                 properties => {
-#pod                     id => { type => 'integer' },
+#pod                     id => {
+#pod                         type => 'integer',
+#pod                         readOnly => 1,
+#pod                     },
 #pod                     name => { type => 'string' },
 #pod                     email => { type => 'string' },
 #pod                 },
@@ -160,7 +166,7 @@ Yancy::Backend::Mysql - A backend for MySQL using Mojo::mysql
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -228,7 +234,10 @@ You could map that schema to the following collections:
             People => {
                 required => [ 'name', 'email' ],
                 properties => {
-                    id => { type => 'integer' },
+                    id => {
+                        type => 'integer',
+                        readOnly => 1,
+                    },
                     name => { type => 'string' },
                     email => { type => 'string' },
                 },
@@ -236,7 +245,10 @@ You could map that schema to the following collections:
             Business => {
                 required => [ 'name' ],
                 properties => {
-                    id => { type => 'integer' },
+                    id => {
+                        type => 'integer',
+                        readOnly => 1,
+                    },
                     name => { type => 'string' },
                     email => { type => 'string' },
                 },
